<?php

/**
 * Copyright (c) D3 Data Development (Inh. Thomas Dartsch)
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 *
 * https://www.d3data.de
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Daniel Seifert <info@shopmodule.com>
 * @link      https://www.oxidmodule.com
 */

declare(strict_types=1);

namespace D3\LoggerFactory;

use Monolog\Logger;
use Monolog\Processor\UidProcessor;
use RuntimeException;

trait ProcessorsTrait
{
    public function applyProcessors($logger, array $processorFlags): Logger
    {
        $this->applyUidProcessor($processorFlags, $logger);
        $this->applyFilterSensitiveProcessor($processorFlags, $logger);

        return $logger;
    }

    /**
     * @param array $processorFlags
     * @param $logger
     * @return void
     */
    protected function applyUidProcessor(array $processorFlags, $logger): void
    {
        if (in_array(self::PROCESSOR_UNIQUE_ID, $processorFlags, true)) {
            $logger->pushProcessor(new UidProcessor());
        }
    }

    /**
     * @param array $processorFlags
     * @param $logger
     * @return void
     */
    protected function applyFilterSensitiveProcessor(array $processorFlags, $logger): void
    {
        if (in_array(self::PROCESSOR_FILTERSENSITIVE, array_keys($processorFlags), true)) {
            $options = $processorFlags[self::PROCESSOR_FILTERSENSITIVE] ?? [];
            $searchList = $options[self::FILTERSENSITIVE_SECRETS] ?? [];

            if (!is_array($searchList)) {
                throw new RuntimeException('sensitive list must be an array');
            }

            $logger->pushProcessor(new SensitiveFilterProcessor($searchList));
        }
    }
}